#
# spec file for package fwnn
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define base_version 1.1.1
%define alpha_version a023.1
Name:           fwnn
Version:        1.1.1a023.1
Release:        4.4
Summary:        FreeWnn Japanese Input System--Server Only
License:        GPL-2.0-or-later
Group:          System/I18n/Japanese
URL:            http://freewnn.sourceforge.jp/
# Upstream hasn't released tarball yet.
# I entered the following commands.
# cvs -d :pserver:anonymous@cvs.osdn.net:/cvsroot/freewnn export -r freewnn-1-1-1-a023-1 -d FreeWnn-1.1.1-a023.1 FreeWnn
# tar --xz -cf FreeWnn-1.1.1-a023.1.tar.xz FreeWnn-1.1.1-a023.1
Source:         FreeWnn-%{base_version}-%{alpha_version}.tar.xz
Source1:        FreeWnn-%{base_version}-%{alpha_version}.tar.xz.asc
Source2:        %{name}.keyring
Source5:        fwnn.service
Source6:        fcwnn.service
Source7:        fkwnn.service
Source8:        ftwnn.service
Source99:       fwnn-rpmlintrc
Patch0:         FreeWnn-fsstnd.patch
Patch1:         FreeWnn-ja.patch
# PATCH-FIX-UPSTREAM don't install as wnn user and don't setuid/setgid
Patch2:         FreeWnn-noroot.patch
Patch7:         FreeWnn-s390x.patch
Patch8:         FreeWnn-warnings.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  tcpd-devel
Requires:       fwnncom = %{version}
# %%{_sbindir}/useradd
Requires(pre):  shadow
Conflicts:      wnn6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
FreeWnn is a Kana-Kanji translation system intended as a system
powerful enough to translate entire sentences at once.

Wnn works in a client/server manner. The server portion of Wnn, or
jserver, is used as a Kana-Kanji translation engine for clients like
"xwnmo" and "kinput2" (input systems for the X Window System) or for
clients like "Egg", which are part of Mule (MUlti-Lingual Emacs) and
XEmacs.

This package contains only the Japanese server.

%package -n libjd0
Summary:        FreeWnn Japanese Input System library
Group:          System/Libraries

%description -n libjd0
This subpackage contains a core library of the Wnn input system.

%package -n libwnn0
Summary:        FreeWnn Input System library
Group:          System/Libraries

%description -n libwnn0
This subpackage contains a core library of the Wnn input system.

%package -n fwnn-devel
Summary:        Development Library and Header Files for FreeWnn
Group:          Development/Libraries/C and C++
Requires:       fcwnn-devel = %{version}
Requires:       fwnn = %{version}
Requires:       libjd0 = %{version}
Requires:       libwnn0 = %{version}
Provides:       fwnndev = %{version}
Obsoletes:      fwnndev < %{version}

%description -n fwnn-devel
This package contains the header files and libraries for building
client programs which use FreeWnn for Japanese input.

%package -n fwnncom
Summary:        Common Files for FreeWnn
Group:          System/I18n/Japanese
Requires(pre):  shadow

%description -n fwnncom
This package includes files you need to run FreeWnn, Free cWnn, Free
tWnn, or Free kWnn.  Install this package if you will be using any part
of the Wnn System.

%package -n fcwnn
Summary:        Free cWnn Chinese Input System (Mainland China)
Group:          System/I18n/Chinese
Requires:       fcwnncom = %{version}
Requires:       fkwnn = %{version}
Requires:       fwnn = %{version}
Requires(pre):  shadow
Requires(post): fcwnncom

%description -n fcwnn
Free cWnn Chinese Input System (mainland China).

%package -n fcwnncom
Summary:        Free cWnn/tWnn Chinese Input System Common Files (Mainland and Taiwan)
Group:          System/I18n/Chinese
Requires:       fwnncom = %{version}
Requires(pre):  shadow

%description -n fcwnncom
This package includes the common files for the Free cWnn and Free tWnn
Chinese Input Systems. Free cWnn is for mainland Chinese and free tWnn
is for Taiwan-Chinese.

%package -n libcwnn0
Summary:        FreeWnn Chinese Input System library
Group:          System/Libraries

%description -n libcwnn0
This subpackage contains a core library of the Wnn input system.

%package -n fcwnn-devel
Summary:        Development Libraries and Header Files for Free cWnn
Group:          Development/Libraries/C and C++
Requires:       fcwnn = %{version}
Requires:       libcwnn0 = %{version}
Obsoletes:      fcwnndev < %{version}-%{release}
Provides:       fcwnndev = %{version}-%{release}

%description -n fcwnn-devel
This package contains the header files and libraries for building
client programs that use the Chinese Input System, Free cWnn.

%package -n ftwnn
Summary:        Free tWnn Chinese Input System (Taiwan)
Group:          System/I18n/Chinese
Requires:       fcwnn = %{version}
Requires:       fcwnncom = %{version}
Requires(pre):  shadow
Requires(post): fcwnncom

%description -n ftwnn
Free tWnn Chinese input system (Taiwan).

%package -n fkwnn
Summary:        Free kWnn Korean Input System
Group:          System/I18n/Korean
Requires:       fwnncom = %{version}
Requires(pre):  shadow

%description -n fkwnn
Free kWnn Korean input system.

%package -n libkwnn0
Summary:        FreeWnn Korean Input System library
Group:          System/Libraries

%description -n libkwnn0
This subpackage contains a core library of the Wnn input system.

%package -n fkwnn-devel
Summary:        Development Libraries and Header Files for Free kWnn
Group:          Development/Libraries/C and C++
Requires:       fcwnn-devel = %{version}
Requires:       fkwnn = %{version}
Obsoletes:      fwknndev < %{version}-%{release}
Provides:       fwknndev = %{version}-%{release}

%description -n fkwnn-devel
This package contains the header files and libraries for building
client programs that use the Korean Input System, Free kWnn.



######################################################################
# package xwnmo
# I don't know how to build xwnmo. Will try that later ...
# %%package -n xwnmo
# Requires: wnn
# Summary: xwnmo - Input Manager for the X11 Window System
# Summary(ja): xwnmo - Ｘウィンドウ・インプットマネージャー
# Group: Applications/X11
#
# %%description -n xwnmo
#
# Xwnmo is a input manager for the Input Method of the X Window System.
# It is based on the X11 Input Method Specifications.  It provides a
# multi-language input environment for multiple clients in the X11
# Window System. Clients can connect to it by using the XIM library. The
# conversion engine xwnmo uses the internationalized Wnn. It selects
# the conversion server in accordance with language of clients.
#
%prep
%setup -q -n FreeWnn-%{base_version}-%{alpha_version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch7 -p2 -b .s390x
%patch8
#%%setup -b 1 -n Xsi           # add include-files for Xwnmo
# SuSE setlocale patch, try to set LC_CTYPE if LC_ALL fails (Xwnmo) and
#......................................................................
# %%patch2 -p1
# Trying to make Xwnmo work...
#..................................................................
# %%patch3 -p1

%build
autoreconf -fi
%configure --prefix=%{_prefix} \
            --libdir=%{_libdir} \
            --mandir=%{_mandir} \
            --infodir=%{_infodir} \
            %{_target_cpu}-suse-linux-gnu \
            --disable-sub-bindir \
            --enable-client \
	    --disable-client-setuid \
	    --disable-client-setgid \
            --with-libwrap
# not -j safe, see Wnn/pubdicplus/Makefile.in
make
#pushd Wnn/uum
#make CCOPTIONS="$RPM_OPT_FLAGS"
#popd

%install
make DESTDIR=%{buildroot} INSTPGMFLAGS= install %{?_smp_mflags}
make install.man DESTDIR=%{buildroot}
#pushd Wnn/uum
#make install DESTDIR=$RPM_BUILD_ROOT INSTPGMFLAGS=
#popd

#----------------------------------------------------------------------
# move Japanese man pages to their correct destination:
# (the above 'make install.man' command installs Japanese AND English
#  manpages, but unfortunately all of them into the same directory.
#  The Japanese manpages should be in a subdirectory 'ja'
#  (or maybe ja_JP.eucJP), therefore I move them here:
for i in 1 3 4 5 ; do
    mkdir -p %{buildroot}/%{_mandir}/ja/man$i
done
for i in atod.1 atof.1 dtoa.1 jserver.1 oldatonewa.1 uum.1 wddel.1 wdreg.1 \
	  wnnkill.1 wnnstat.1 wnntouch.1
do
	  mv %{buildroot}/%{_mandir}/man1/$i %{buildroot}/%{_mandir}/ja/man1/
done
mv %{buildroot}/%{_mandir}/man3/* %{buildroot}/%{_mandir}/ja/man3/
for i in 2a_ctrl.4 2b_romkana.4 cvt_key_tbl.4 fzk.data.4 fzk.u.4 \
	  hinsi_data.4 jserverrc.4 mode.4 serverdefs.4 ujis_dic.4 \
	  uumkey.4 uumrc.4 wnnenvrc.4
do
	  mv %{buildroot}/%{_mandir}/man4/$i %{buildroot}/%{_mandir}/ja/man4/
done
for i in pubdic.5 usr_dic.5
do
	  mv %{buildroot}/%{_mandir}/man5/$i %{buildroot}/%{_mandir}/ja/man5/
done
install -d %{buildroot}%{_unitdir}
install -m 644 %{SOURCE5} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE6} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE7} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE8} %{buildroot}%{_unitdir}
install -d %{buildroot}%{_sbindir}
ln -s -f service %{buildroot}%{_sbindir}/rcfwnn
ln -s -f service %{buildroot}%{_sbindir}/rcfcwnn
ln -s -f service %{buildroot}%{_sbindir}/rcftwnn
ln -s -f service %{buildroot}%{_sbindir}/rcfkwnn
ln -s -f %{_localstatedir}/lib/wnn/ja/dic %{buildroot}%{_sysconfdir}/FreeWnn/ja/dic
ln -s -f %{_localstatedir}/lib/wnn/zh_CN/dic %{buildroot}%{_sysconfdir}/FreeWnn/zh_CN/dic
ln -s -f %{_localstatedir}/lib/wnn/zh_TW/dic %{buildroot}%{_sysconfdir}/FreeWnn/zh_TW/dic
ln -s -f %{_localstatedir}/lib/wnn/ko_KR/dic %{buildroot}%{_sysconfdir}/FreeWnn/ko_KR/dic
#----------------------------------------------------------------------
find %{buildroot} -type f -name "*.la" -delete -print
find %{buildroot} -type f -name "*.a" -delete -print

%fdupes -s %{buildroot}

%pre -n fwnn
%service_add_pre fwnn.service
getent passwd wnn >/dev/null || \
	%{_sbindir}/useradd -r -o -g root -u 66 -s /bin/false \
	-c "Wnn System Account" -d %{_localstatedir}/lib/wnn wnn

%post -n fwnn
%service_add_post fwnn.service
# touch all public dictionary files:
chroot . usr/bin/wnntouch var/lib/wnn/ja/dic/gerodic/g-jinmei.dic
chroot . usr/bin/wnntouch var/lib/wnn/ja/dic/pubdic/*.*

%preun -n fwnn
%service_del_preun fwnn.service
%stop_on_removal fwnn

%postun -n fwnn
%service_del_postun fwnn.service
%restart_on_update fwnn

%post   -n libjd0 -p /sbin/ldconfig
%postun -n libjd0 -p /sbin/ldconfig
%post   -n libwnn0 -p /sbin/ldconfig
%postun -n libwnn0 -p /sbin/ldconfig

%pre -n fwnncom
getent passwd wnn >/dev/null || \
	%{_sbindir}/useradd -r -o -g root -u 66 -s /bin/false \
	-c "Wnn System Account" -d %{_localstatedir}/lib/wnn wnn

%pre -n fcwnncom
getent passwd wnn >/dev/null || \
	%{_sbindir}/useradd -r -o -g root -u 66 -s /bin/false \
	-c "Wnn System Account" -d %{_localstatedir}/lib/wnn wnn

%pre -n fcwnn
%service_add_pre fcwnn.service
getent passwd wnn >/dev/null || \
	%{_sbindir}/useradd -r -o -g root -u 66 -s /bin/false \
	-c "Wnn System Account" -d %{_localstatedir}/lib/wnn wnn

%preun -n fcwnn
%service_del_preun fcwnn.service
%stop_on_removal fcwnn

%post -n fcwnn
%service_add_post fcwnn.service
# touch all public dictionary files:
chroot . usr/bin/cwnntouch var/lib/wnn/zh_CN/dic/sys/*.*
# Create symbolic run level links:

%postun -n fcwnn
%service_del_postun fcwnn.service
%restart_on_update fcwnn

%post   -n libcwnn0 -p /sbin/ldconfig
%postun -n libcwnn0 -p /sbin/ldconfig

%pre -n ftwnn
%service_add_pre ftwnn.service
getent passwd wnn >/dev/null || \
	%{_sbindir}/useradd -r -o -g root -u 66 -s /bin/false \
	-c "Wnn System Account" -d %{_localstatedir}/lib/wnn wnn

%preun -n ftwnn
%service_del_preun ftwnn.service
%stop_on_removal ftwnn

%post -n ftwnn
%service_add_post ftwnn.service
# touch all public dictionary files:
chroot . usr/bin/cwnntouch var/lib/wnn/zh_TW/dic/sys/*.*
# Create symbolic run level links:

%postun -n ftwnn
%service_del_postun ftwnn.service
%restart_on_update ftwnn

%pre -n fkwnn
%service_add_pre fkwnn.service
getent passwd wnn >/dev/null || \
	%{_sbindir}/useradd -r -o -g root -u 66 -s /bin/false \
	-c "Wnn System Account" -d %{_localstatedir}/lib/wnn wnn

%preun -n fkwnn
%service_del_preun fkwnn.service
%stop_on_removal fkwnn

%post -n fkwnn
%service_add_post fkwnn.service
# touch all public dictionary files:
chroot . usr/bin/kwnntouch var/lib/wnn/ko_KR/dic/sys/*.*
# Create symbolic run level links:

%postun -n fkwnn
%service_del_postun fkwnn.service
%restart_on_update fkwnn

%post   -n libkwnn0 -p /sbin/ldconfig
%postun -n libkwnn0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_sbindir}/rcfwnn
%{_unitdir}/fwnn.service
%{_bindir}/atod
%{_bindir}/dtoa
%{_bindir}/oldatonewa
%{_bindir}/wdreg
%{_bindir}/wnnstat
%{_bindir}/atof
%{_bindir}/jserver
%{_bindir}/wddel
%{_bindir}/wnnkill
%{_bindir}/uum
%{_bindir}/wnntouch
%dir %attr(-,wnn,root) %{_localstatedir}/lib/wnn/
%dir %attr(-,wnn,root) %{_localstatedir}/lib/wnn/ja/
%attr(-,wnn,root) %{_localstatedir}/lib/wnn/ja/dic
%dir %{_sysconfdir}/FreeWnn/ja/
%{_sysconfdir}/FreeWnn/ja/dic
%config %{_sysconfdir}/FreeWnn/ja/hinsi.data
%config %{_sysconfdir}/FreeWnn/ja/jserverrc
%config %{_sysconfdir}/FreeWnn/ja/libwnn.msg
%config %{_sysconfdir}/FreeWnn/ja/rk
%config %{_sysconfdir}/FreeWnn/ja/rk.vi
%config %{_sysconfdir}/FreeWnn/ja/uum.msg
%config %{_sysconfdir}/FreeWnn/ja/uumkey
%config %{_sysconfdir}/FreeWnn/ja/uumkey.omr
%config %{_sysconfdir}/FreeWnn/ja/uumkey_e
%config %{_sysconfdir}/FreeWnn/ja/uumrc
%config %{_sysconfdir}/FreeWnn/ja/uumrc.omr
%config %{_sysconfdir}/FreeWnn/ja/uumrc.rev
%config %{_sysconfdir}/FreeWnn/ja/uumrc_e
%config %{_sysconfdir}/FreeWnn/ja/uumrc_vi
%config %{_sysconfdir}/FreeWnn/ja/wnnenvrc
%config %{_sysconfdir}/FreeWnn/ja/wnnenvrc.omr
%config %{_sysconfdir}/FreeWnn/ja/wnnenvrc.rem
%config %{_sysconfdir}/FreeWnn/ja/wnnenvrc.rev
%config %{_sysconfdir}/FreeWnn/ja/wnnenvrc_R
%config %{_sysconfdir}/FreeWnn/ja/wnnenvrc_R.omr
%config %{_sysconfdir}/FreeWnn/ja/wnnenvrc_R.rem
%config %{_sysconfdir}/FreeWnn/ja/wnnstat.msg
%dir %{_sysconfdir}/FreeWnn/lt_LN/
%dir %{_sysconfdir}/FreeWnn/lt_LN/rk
%config %{_sysconfdir}/FreeWnn/lt_LN/rk/*
%config %{_sysconfdir}/FreeWnn/lt_LN/uum.msg
%config %{_sysconfdir}/FreeWnn/lt_LN/uumkey
%config %{_sysconfdir}/FreeWnn/lt_LN/uumkey_e
%config %{_sysconfdir}/FreeWnn/lt_LN/uumrc

%files -n libjd0
%defattr(-,root,root)
%{_libdir}/libjd.so.0*

%files -n libwnn0
%defattr(-,root,root)
%{_libdir}/libwnn.so.0*

%files -n fwnn-devel
%defattr(-,root,root)
%{_includedir}/wnn/
%{_libdir}/libjd.so
%{_libdir}/libwnn.so

%files -n fwnncom
%defattr(-,root,root)
%doc CONTRIBUTORS COPYRIGHT COPYRIGHT-j ChangeLog ChangeLog.old
%doc olddoc/ Wnn/manual/ Wnn/manual.en/
%doc cWnn/manual cWnn/manual.en
%{_mandir}/man?/*
%dir %{_mandir}/ja/
%dir %{_mandir}/ja/*/
%{_mandir}/ja/man?/*
%dir %attr(-,wnn,root) %{_localstatedir}/lib/wnn
%dir %{_sysconfdir}/FreeWnn/
%config %{_sysconfdir}/FreeWnn/cvt_key_empty
%config %{_sysconfdir}/FreeWnn/cvt_key_tbl
%config %{_sysconfdir}/FreeWnn/cvt_key_tbl.ST
%config %{_sysconfdir}/FreeWnn/cvt_key_tbl.gm
%config %{_sysconfdir}/FreeWnn/cvt_key_tbl.kt
%config %{_sysconfdir}/FreeWnn/cvt_key_tbl.mv
%config %{_sysconfdir}/FreeWnn/cvt_key_tbl.vt
%config %{_sysconfdir}/FreeWnn/serverdefs

%files -n fcwnn
%defattr(-,root,root)
%{_sbindir}/rcfcwnn
%{_unitdir}/fcwnn.service
%{_bindir}/cserver
%config %{_sysconfdir}/FreeWnn/zh_CN/cixing.data
%config %{_sysconfdir}/FreeWnn/zh_CN/cserverrc
%{_sysconfdir}/FreeWnn/zh_CN/dic
%dir %attr(-,wnn,root) %{_localstatedir}/lib/wnn/
%dir %attr(-,wnn,root) %{_localstatedir}/lib/wnn/zh_CN/
%{_localstatedir}/lib/wnn/zh_CN/dic
%config %{_sysconfdir}/FreeWnn/zh_CN/libwnn.msg
%dir %{_sysconfdir}/FreeWnn/
%dir %{_sysconfdir}/FreeWnn/zh_CN/
%dir %{_sysconfdir}/FreeWnn/zh_CN/rk
%dir %{_sysconfdir}/FreeWnn/zh_CN/rk_p
%dir %{_sysconfdir}/FreeWnn/zh_CN/rk_z
%config %{_sysconfdir}/FreeWnn/zh_CN/rk/*
%config %{_sysconfdir}/FreeWnn/zh_CN/rk_p/*
%config %{_sysconfdir}/FreeWnn/zh_CN/rk_z/*
%config %{_sysconfdir}/FreeWnn/zh_CN/uum.msg
%config %{_sysconfdir}/FreeWnn/zh_CN/uumkey
%config %{_sysconfdir}/FreeWnn/zh_CN/uumkey_e
%config %{_sysconfdir}/FreeWnn/zh_CN/uumkey_p
%config %{_sysconfdir}/FreeWnn/zh_CN/uumrc
%config %{_sysconfdir}/FreeWnn/zh_CN/uumrc_p
%config %{_sysconfdir}/FreeWnn/zh_CN/uumrc_z
%config %{_sysconfdir}/FreeWnn/zh_CN/wnnenvrc
%config %{_sysconfdir}/FreeWnn/zh_CN/wnnenvrc_Qi
%config %{_sysconfdir}/FreeWnn/zh_CN/wnnenvrc_QiR
%config %{_sysconfdir}/FreeWnn/zh_CN/wnnenvrc_R
%config %{_sysconfdir}/FreeWnn/zh_CN/wnnenvrc_Wu
%config %{_sysconfdir}/FreeWnn/zh_CN/wnnenvrc_WuR
%config %{_sysconfdir}/FreeWnn/zh_CN/wnnstat.msg

%files -n libcwnn0
%defattr(-,root,root)
%{_libdir}/libcwnn.so.0*

%files -n fcwnncom
%defattr(-,root,root)
%{_bindir}/catod
%{_bindir}/catof
%{_bindir}/cdtoa
%{_bindir}/cwddel
%{_bindir}/cwdreg
%{_bindir}/cwnnkill
%{_bindir}/cwnnstat
%{_bindir}/cwnntouch
%{_bindir}/cuum

%files -n fcwnn-devel
%defattr(-,root,root)
%{_includedir}/cwnn/
%{_libdir}/libcwnn.so

%files -n ftwnn
%defattr(-,root,root)
%{_sbindir}/rcftwnn
%{_unitdir}/ftwnn.service
%{_bindir}/tserver
%config %{_sysconfdir}/FreeWnn/zh_TW/cixing.data
%{_sysconfdir}/FreeWnn/zh_TW/dic
%dir %attr(-,wnn,root) %{_localstatedir}/lib/wnn/
%dir %attr(-,wnn,root) %{_localstatedir}/lib/wnn/zh_TW/
%{_localstatedir}/lib/wnn/zh_TW/dic
%config %{_sysconfdir}/FreeWnn/zh_TW/libwnn.msg
%dir %{_sysconfdir}/FreeWnn/
%dir %{_sysconfdir}/FreeWnn/zh_TW/
%dir %{_sysconfdir}/FreeWnn/zh_TW/rk
%dir %{_sysconfdir}/FreeWnn/zh_TW/rk_p
%dir %{_sysconfdir}/FreeWnn/zh_TW/rk_z
%config %{_sysconfdir}/FreeWnn/zh_TW/rk/*
%config %{_sysconfdir}/FreeWnn/zh_TW/rk_p/*
%config %{_sysconfdir}/FreeWnn/zh_TW/rk_z/*
%config %{_sysconfdir}/FreeWnn/zh_TW/tserverrc
%config %{_sysconfdir}/FreeWnn/zh_TW/uum.msg
%config %{_sysconfdir}/FreeWnn/zh_TW/uumkey
%config %{_sysconfdir}/FreeWnn/zh_TW/uumkey_e
%config %{_sysconfdir}/FreeWnn/zh_TW/uumkey_p
%config %{_sysconfdir}/FreeWnn/zh_TW/uumrc
%config %{_sysconfdir}/FreeWnn/zh_TW/uumrc_p
%config %{_sysconfdir}/FreeWnn/zh_TW/uumrc_z
%config %{_sysconfdir}/FreeWnn/zh_TW/wnnenvrc
%config %{_sysconfdir}/FreeWnn/zh_TW/wnnenvrc_R
%config %{_sysconfdir}/FreeWnn/zh_TW/wnnstat.msg

%files -n fkwnn
%defattr(-,root,root)
%{_sbindir}/rcfkwnn
%{_unitdir}/fkwnn.service
%{_bindir}/kserver
%{_bindir}/katod
%{_bindir}/katof
%{_bindir}/kdtoa
%{_bindir}/kwddel
%{_bindir}/kwdreg
%{_bindir}/kwnnkill
%{_bindir}/kwnnstat
%{_bindir}/kwnntouch
%{_bindir}/kuum
%dir %{_sysconfdir}/FreeWnn/
%dir %{_sysconfdir}/FreeWnn/ko_KR/
%{_sysconfdir}/FreeWnn/ko_KR/dic
%dir %attr(-,wnn,root) %{_localstatedir}/lib/wnn/
%dir %attr(-,wnn,root) %{_localstatedir}/lib/wnn/ko_KR/
%{_localstatedir}/lib/wnn/ko_KR/dic
%config %{_sysconfdir}/FreeWnn/ko_KR/hinsi.data
%config %{_sysconfdir}/FreeWnn/ko_KR/kserverrc
%config %{_sysconfdir}/FreeWnn/ko_KR/libwnn.msg
%dir %{_sysconfdir}/FreeWnn/ko_KR/rk
%config %{_sysconfdir}/FreeWnn/ko_KR/rk/*
%config %{_sysconfdir}/FreeWnn/ko_KR/uum.msg
%config %{_sysconfdir}/FreeWnn/ko_KR/uumkey
%config %{_sysconfdir}/FreeWnn/ko_KR/uumrc
%config %{_sysconfdir}/FreeWnn/ko_KR/wnnenvrc
%config %{_sysconfdir}/FreeWnn/ko_KR/wnnenvrc_R
%config %{_sysconfdir}/FreeWnn/ko_KR/wnnstat.msg

%files -n libkwnn0
%defattr(-,root,root)
%{_libdir}/libkwnn.so.0*

%files -n fkwnn-devel
%defattr(-,root,root)
%{_includedir}/kwnn/
%{_libdir}/libkwnn.so
# I don't know how to build xwnmo. Will try that later ...
# %%files -n xwnmo
# %%doc Xwnmo/manual Xwnmo/manual.en Xwnmo/README Xwnmo/README.j
# %%doc Xwnmo/X11R6/README Xwnmo/X11R6/include/README
# %%doc Xwnmo/xjutil/README Xwnmo/xjutil/README.j Xwnmo/xwnmo/README
# %%doc Xwnmo/xwnmo/README.j Xwnmo/xwnmo/SEP_README Xwnmo/xwnmo/SEP_README.j
# /usr/X11R6/lib/X11/app-defaults/Xwnmo
# /usr/X11R6/bin/xwnmo
# /usr/X11R6/bin/killxwnmo
# /usr/X11R6/bin/xjutil
# /usr/X11R6/man/ja_JP.ujis/man1/xwnmo.1.gz
# /usr/X11R6/man/ja_JP.ujis/man1/ximrc.1.gz
# /usr/X11R6/man/ja_JP.ujis/man1/ximconf.1.gz
# /usr/X11R6/man/ja_JP.ujis/man1/cvt_fun_tbl.1.gz
# /usr/X11R6/man/ja_JP.ujis/man1/cvt_meta_tbl.1.gz
# /usr/X11R6/man/ja_JP.ujis/man1/killxwnmo.1.gz
# /usr/X11R6/man/ja_JP.ujis/man1/cvt_xim_tbl.1.gz
# /usr/X11R6/man/ja_JP.ujis/man1/xjutil.1.gz
# /usr/X11R6/man/man1/xwnmo.1.gz
# /usr/X11R6/man/man1/ximrc.1.gz
# /usr/X11R6/man/man1/ximconf.1.gz
# /usr/X11R6/man/man1/cvt_fun_tbl.1.gz
# /usr/X11R6/man/man1/cvt_meta_tbl.1.gz
# /usr/X11R6/man/man1/killxwnmo.1.gz
# /usr/X11R6/man/man1/cvt_xim_tbl.1.gz
# /usr/X11R6/man/man1/xjutil.1.gz
# /var/lib/wnn/ja_JP/uumrc.xim
# /var/lib/wnn/ja_JP/uumrc_vi.xim
# /var/lib/wnn/ja_JP/uumrc_e.xim
# /var/lib/wnn/ja_JP/uumkey.xim
# /var/lib/wnn/ja_JP/uumkey_v.xim
# /var/lib/wnn/ja_JP/uumkey_e.xim
# /var/lib/wnn/ja_JP/xim.msg
# /var/lib/wnn/ja_JP/xjutil.msg
# /var/lib/wnn/lt_LN/uumrc.xim
# /var/lib/wnn/lt_LN/uumkey.xim
# /var/lib/wnn/lt_LN/xim.msg
# /var/lib/wnn/zh_CN/uumrc.xim
# /var/lib/wnn/zh_CN/uumrc_p.xim
# /var/lib/wnn/zh_CN/uumrc_z.xim
# /var/lib/wnn/zh_CN/uumkey.xim
# /var/lib/wnn/zh_CN/uumkey_p.xim
# /var/lib/wnn/zh_CN/xim.msg
# /var/lib/wnn/zh_CN/xjutil.msg
# /var/lib/wnn/zh_TW/uumrc.xim
# /var/lib/wnn/zh_TW/uumrc_p.xim
# /var/lib/wnn/zh_TW/uumrc_z.xim
# /var/lib/wnn/zh_TW/uumkey.xim
# /var/lib/wnn/zh_TW/uumkey_p.xim
# /var/lib/wnn/zh_TW/xim.msg
# /var/lib/wnn/zh_TW/xjutil.msg
# /var/lib/wnn/ko_KR/uumrc.xim
# /var/lib/wnn/ko_KR/uumkey.xim
# /var/lib/wnn/ko_KR/xim.msg
# /var/lib/wnn/ko_KR/xjutil.msg
# %%config /var/lib/wnn/ximconf
# %%config /var/lib/wnn/ximrc
# %%config /var/lib/wnn/ximrc_vi
# %%config /var/lib/wnn/cvt_xim_tbl

%changelog
* Tue Oct 25 2022 Matthias Gerstner <matthias.gerstner@suse.com>
- Fix generation of debuginfo packages. The IMake based build system by
  default strips binaries during `make install` phase already. Avoid this by
  overriding the corresponding make variable.
* Thu Sep 16 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * fcwnn.service
  * fkwnn.service
  * ftwnn.service
  * fwnn.service
* Wed Aug 21 2019 Berthold Gunreben <azouhr@opensuse.org>
- run autoreconf because delievered configure is too old for
  link time optimization
* Sat Mar 16 2019 bkbin005@rinku.zaq.ne.jp
- Remove tarball's URL: Upstream hasn't released tarball yet.
* Fri Mar 15 2019 Jan Engelhardt <jengelh@inai.de>
- Do not hide errors coming from useradd.
* Sat Mar  9 2019 bkbin005@rinku.zaq.ne.jp
- Update to FreeWnn-1.1.1-a023.1:
  * Deal with "Reproducible Buids".
    See <https://osdn.net/projects/freewnn/ticket/38482>.
- Remove FreeWnn-trad_cpp.patch: doesn't seem to need.
* Thu Mar  7 2019 josef.moellers@suse.com
- Added systemd support: Replaced sysv init files by systemd
  service files.
  [bsc#1116014,fwnn.service,fcwnn.service,fkwnn.service,
  ftwnn.service]
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Mon Jun 13 2016 jengelh@inai.de
- Implement shared library guideline
- Condense description to present the main idea
- Rename development subpackages to *-devel
* Tue Jun  7 2016 mpost@suse.com
- Removed %%{?_smp_mflags} from the make command to fix a build
  failure on the s390x architecture.
* Fri Dec 25 2015 i@marguerite.su
- add Requires: fcwnndev to fkwnndev and fwnn-devel,
  or the header files of the later two would be
  dangling symlinks
- add Requires: fkwnn/fwnn to fcwnn, or files in etc/FreeWnn
  would be dangling symlinks
- add Requires: fcwnn to ftwnn, or files in etc/FreeWnn
  would be dangling symlinks
- remove redundant Requires: fwnncom from fcwnn, ftwnn,
  because they requires fcwnncom that has already required
  fwnncom
- the dangling symlinks mentioned above can't be fixed
  by fdupes simply
* Wed Sep 16 2015 werner@suse.de
- Some cleanups like
  + use the same owner for /var/lib/wnn as the package canna does
  + mark configuration files as configuration files
  + avoid warning due missed header files
* Sat Sep 12 2015 i@marguerite.su
- update to 1.1.1-a023
  * Merge modificaion used in OpenSUSE packages by new member,
    Mitsutoshi NAKANO. Added explicit function prototype and
    cast in many places, so we reduced unpredictable effect
    on 64bit environment.
  * As a consequence of this change, #define of WNN_CREATE /
    WNN_NO_CREATE in jl_dic_create() is also changed. We
    believe no change is needed for client build, but please
    report if you have problems.
  * Exit status of jserver changed on receiving some signals
    (ex. SIGTERM). (Not well documented.)
  * Fixed problem for parallel build (ex. make -jXX) on pubdic+.
- drop patch: FreeWnn-sighandler.patch, upstreamed
- drop patch: FreeWnn-include.patch, upstreamed
- drop patch: FreeWnn-prototypes.patch, upstreamed
- drop patch: FreeWnn-prototypes_msg.patch, upstreamed
- drop patch: FreeWnn-1.1.1-a022.dif, upstreamed
- drop patch: FreeWnn-prototypes_3.patch, upstreamed
* Thu Aug 15 2013 bkbin005@rinku.zaq.ne.jp
- Modify FreeWnn-prototypes_3.patch .
  I found a bug in make_hinsi_list() at Wnn/jserver/hinsi_list.c,
  then fixed it .
* Thu Aug 15 2013 bkbin005@rinku.zaq.ne.jp
- Add FreeWnn-prototypes_3.patch .
  Prototype declarations for reducing compilation warnings .
* Fri Aug  9 2013 bkbin005@rinku.zaq.ne.jp
- Add FreeWnn-prototypes_msg.patch .
  Bugfix: In openSUSE 13.1 Milestone 3,
  uum could not get error messages .
  This issue's cause is that we forgot prototype declaration
  of msg_get() in Wnn/include/msg.h .
  Then I added "FreeWnn-prototypes_msg.patch" as %%Patch15 .
  http://lists.opensuse.org/opensuse-ja/2013-08/msg00014.html
  http://sourceforge.jp/projects/freewnn/lists/archive/users/2013-August/000140.html
- I added %%configure --with-libwrap option .
  The [jctk]server s were linked -lwrap .
  Then we can use /etc/hosts.allow /etc/hosts.deny .
- Degrade fix: In "FreeWnn-prototypes.patch",
  I invalidated the patch of "FreeWnn-sighandler.patch" .
  Then I deleted a wrong patch to "Wnn/jserver/de.c"
  from "FreeWnn-prototypes.patch" .
  http://sourceforge.jp/projects/freewnn/lists/archive/users/2013-August/000141.html
- Change: In "FreeWnn-sighandler.patch",
  I changed from _exit(-1) to _exit(255) .
  This change effects [jctk]server's exit status .
* Thu Aug  8 2013 bkbin005@rinku.zaq.ne.jp
- SLE_11 and openSUSE 12.2 does not provide libwrap0,
  then I could not build FreeWnn on them .
  So, I deleted %%configure --with-libwrap option
  and "BuildRequires: libwrap0" from fwnn.spec file .
* Wed Aug  7 2013 bkbin005@rinku.zaq.ne.jp
- The uum can use UNIX 98 pseudoterminal now . (bnc#830533)
  https://bugzilla.novell.com/show_bug.cgi?id=830533
- The kuum is packaged in fkwnn .
- The cuum is packaged in fcwnncom .
- The [jctk]server s were linked -lwrap .
  Then we can use /etc/hosts.allow /etc/hosts.deny .
- This release need not link to -ltermcap, but use ncurses,
  then fwnn.spec was changed .
- FreeWnn-trad_cpp.patch:
  Makefile.in s were changed formats, then remade the patch .
- FreeWnn-prototypes.patch:
  Already, many functions were added prototype decraretion
  in the tarball, then remade this patch .
- FreeWnn-returnvalue.diff:
  Already, the tarball's source was fixed about return value .
  Then this patch was removed .
- FreeWnn-include.patch:
  Many sources already included proper header files .
  Then this patch was remade .
- Freewnn-1.1.1-a21.dif was deleted,
  but Freewnn-1.1.1-a22.dif was added:
  In Wnn/include/jllib.h, many functions were added
  prototype decraretion in the tarball,
  then they need not to declare in the patch .
  In Wnn/jlib/jlib.c, wrong cast changed .
- FreeWnn-uum.patch, fwnn.spec:
  Now, FreeWnn need not to use -ltermcap,
  but need to use -lncursess, then this patch was deleted .
  And "BuildRequires:" was changed from termcap to ncurses
  in fwnn.spec .
- FreeWnn-ja.patch:
  FreeWnn-1.1.1-a017/Xsi/Wnn/uum/header.c was changed , then remade it .
- Fwnn-fsstnd-patch:
  Changed makerule.mk.in format, then remade it .
- FreeWnn 1.1.1-a-22 released .
  * Removed strange word (pronounces as 'Hirokazu', transfers to
    'Kobayashi'). Spotted by some poster of FreeWnn thread in
    2ch.net
    (http://toro.2ch.net/test/read.cgi/unix/1084551838/458)
  * uum failed to start on traditional systems because opening
    tty fails. Fixed open_pty_traditional()
    to set tty_slave correctly.
  * Improve libutil detection. Systems that have both ptsname() and
    openpty() does not need libutil, this change (probably)
    covers these systems. ([freewnn-users 133]).
    http://sourceforge.jp/projects/freewnn/lists/archive/users/2013-August/000132.html
  * libutil is (may be) used only in uum, so separate this library
    (if exists) from normal LIBS.
    Patch by 1xx (itsango at gmail.com) ([freewnn-users 126])
    http://sourceforge.jp/projects/freewnn/lists/archive/users/2013-July/000125.html
    .
  * Pass CPPFLAGS and LDFLAGS on configure / make.
    Original suggestion by Hideki Yamane, but arranged a bit.
  * Wnn/uum/inspect.c:
    Fix typo in comment.
  * Wnn/: jutil/wddel.c, jutil/wdreg.c, uum/inspect.c,
    uum/select_ele.c:
  * Quick fix for warning about format-security by gcc.
    Based on patch by Hideki Yamane and Makoto Fujiwara
    ([Freewnn-users 102]).
    http://sourceforge.jp/projects/freewnn/lists/archive/users/2012-May/000101.html
    Replacing from sprintf() to snprintf() or strncat()
    would be better.
  * (Wnn/jutil/wddel.c) Change (fix?) type of Com[] to w_char
    in code for 'wddel -C' mode. I think I'm doing right,
    but not tested.
  * Strip old mail address (as usual).
  * configure, configure.in, Wnn/jutil/Makefile.in,
    Wnn/uum/Makefile.in, cWnn/jutil/Makefile.in,
    cWnn/uum/Makefile.in, kWnn/jutil/Makefile.in,
    kWnn/uum/Makefile.in:
    Fix to work --with-*wnn-includes .
    Same as --with-*wnn-libraries , these are enabled
    on *Wnn/jutil and *Wnn/uum only.
  * Fix to work as expected in case --without-lib*wnn is explicitly
    specified.
  * Wnn/jserver/renbn_kai.c:
  * Explicitly add cast to pointer in tan_syo().
    It helps compilers to guess argument type of sbn_kai(),
    and fix other jserver crash bug on Linux/amd64 .
  * Wnn/jserver/de_header.h:
    Added prototype declaration of functions in bnsetu_kai.c
    (for safety) .
  * configure, configure.in:
    We cannot build Xwnmo for now, so we (temporally) disabled
    AC_PATH_X .
    Probably workaround for systems with modern install layout
    of X11.
  * Wnn/jserver/de_header.h:
    Fix return type mismatch of kanjiaddr()
    prototype declaration .
    Spotted on
    http://twitter.com/pachira23/status/8875168688513024 ,
    and reported to freewnn-users by Hideki Yamane. Original
    reporter saids it also fixes crash bug of jserver when client
    register new word to dictionary.
  * Add prototype declaration of functions in bdic.c (and some
    source files).
  * Wnn/jutil/ujisf.c:
    Added prototype declaration of kanjiaddr() and Print_entry() .
  * INSTALL, configure, configure.in, makerule.mk.in,
    Wnn/jserver/Makefile.in, Wnn/jutil/Makefile.in,
    Wnn/man/4.cmd/Makefile.in, Wnn/man/6.jutil/Makefile.in,
    Wnn/uum/Makefile.in, cWnn/jserver/Makefile.in,
    cWnn/jutil/Makefile.in, cWnn/man/4.cmd/Makefile.in,
    cWnn/man/6.jutil/Makefile.in, cWnn/uum/Makefile.in,
    kWnn/jserver/Makefile.in, kWnn/jutil/Makefile.in,
    kWnn/uum/Makefile.in:
    Added (first step of) support for new installation path
    layout .
    Maybe useful for package managers .
  * Makefile.in:
    Remove rules that exist on makerule.mk. make install
    (for example) runs two times faster :-p
  * configure, configure.in, makerule.mk.in,
    Wnn/pubdicplus/Makefile.in, cWnn/cdic/Makefile.in,
    cWnn/tdic/Makefile.in, kWnn/kdic/Makefile.in:
    Recent cpp of gcc (at least 4.4) splits line that has many
    characters per line (in C language manner). This is problem
    on *.fzk (pubdic etc.)  file processing. So adds
  - traditional-cpp parameter to cpp
    (at least gcc-2.95 passes this parameter).
    Simply adding it to CPPFLAGS may break other build,
    so split FZK_PP (cpp for text processing) from normal CPP .
    Spotted by some posters of FreeWnn thread in 2ch.net .
    (Other changes)
  * Use AC_SEARCH_LIBS for libnsl checking
    (Linux (for example) does not need it) .
  * Modified to build correctly if builddir != srcdir (as usual).
  * Wnn/: man/2.env/wnn/2b_romkan.man, manual/2.env/wnn/2b_romkana:
  * Change '\' to '\e' to correctly format backslash
    in man file .
    (Also change formatted text file.)
    It should reduce Debian lintian warning .
  * Added .nf / .fi to pre-formatted table.
  * Wnn/uum/setutmp.c:
  * Stop checking return value of pututline()
    because many systems does not have return value
    of this function.
  * Change handling of ut_err to work correctly
    (especially on systems that have utmp (pututline())
    without utmpx)  .
  * aclocal.m4, config.guess, config.sub, configure, ltmain.sh:
    Update libtool to 1.5.26
    (last release of 1.5 series - bit old).
  * (jhlp.c) Check owner / permission of ttyp (tty_slave / ttypfd)
    on open_ttyp(). If check (and chown/chmod) fails,
    uum warns it may be insecure (ttyp readable)
    from other local users.
    (Probably you need proper privileges to uum
    (ex. setuid-root) .  )
  * (jhlp.c) Verbose error message on restoring owner
    / permission of tty_master and ttyp in do_end() .
  * (sheader.h) Added Prototype of openTermData() / getTermData() .
  * Wnn/jlib/Makefile.in, Wnn/jlib.V3/Makefile.in,
    cWnn/jlib/Makefile.in, kWnn/jlib/Makefile.in:
  * Tell Libtool to use external libraries needed for libwnn (and
    lib[ck]wnn). (ex. libcrypt, libnsl)
    You don't need detection of these libraries to use libwnn
    itself in configure (I hope).
  * Use LT_LD to link libraries.
  * (*Wnn/jlib/Makefile.in) Remove definition of LT_{CC,INSTALL}
    because we already defined in makerule.mk .
  * (Wnn/jlib.V3/Makefile.in) Make use of LT_{CC,INSTALL}
    in makerule.mk to reduce libtool warning .
  * (Wnn/jlib.V3/Makefile.in) My usual work to build correctly
    if builddir != srcdir .
  * Wnn/include/: jllib.h, jslib.h:
  * Added prototype (and simple macro (FRWNN_PARAMS) around the
    parameters for good-old C compilers) or jslib.h / jllib.h .
    Parameters are came from js.c / jl.c .
  * Added extern "C" { ... } for C++ clients.
  * cWnn/man/2.env/ckey.man:
  * Added .nf / .fi to pre-formatted table.
  * INSTALL, INSTALL.en, configure, configure.in, makerule.mk.in,
    Wnn/uum/Makefile.in, cWnn/uum/Makefile.in,
    kWnn/uum/Makefile.in:
  * Added detection code if your system need to install uum as
    set-[ug]id program on configure time.
    Recent systems may install uum as normal program
    (to reduce security risk) .
    You can also specify
  - -enable-client-setuid / --enable-client-setgid=group
    (group must be specified) to control set-[ug]id of uum .
    (NOTE: SUSE/openSUSE are using --disable-client-setuid
    and --disable-client-setgid .  )
  * Added uum-related option to INSTALL* file .
  * Use modern style AC_INIT. (added pseudo(?) version number and
    contact address. comments are welcome.)
  * Wnn/uum/epilogue.c:
    epilogue_no_close(): Replaced to HAVE_TERMINFO
    (maybe it's right) .
  * config.h.in, configure, configure.in, Wnn/uum/jhlp.c:
    Use posix_openpt() (if it and ptsname() exists)
    when opening tty .
    Traditional pts system (that doesn't have posix_openpt())
    fallback to dummy function opening /dev/ptmx directly.
    Getting tty without	setting setuid root works in non-pts
    systems that have posix-compatible pty functions
    (ex. recent FreeBSD) . (bnc#830533)
  * Other changes to configure.in:
    Commented out useless AC_DEFINE in term library detection
    part .
  * jhlp.c:
  * Mask IEXTEN in j_term_init().
  * Use tty_master for systems that has /dev/ptmx and not have
    ptsname(). (ex. old Debian (2.1 or so))
  * Added comment.
  * termio.c:
  * Use tparm() as macro for fixed parameter system (ex. SVR4) .
  * Wnn/uum/jhlp.c:
    More use of USE_LINUX_TERM in exec_cmd()
    (as of original canuum patch) .
    And window size setting code moved from Linux specific
    to generic .
  * config.h.in, configure, configure.in:
    Added configure test for setsid(). (I forgot it.)
  * config.h.in, configure, configure.in, Wnn/uum/jhlp.c,
    Wnn/uum/setutmp.c:
    More utmp fix:
  * Fix build (more) correctly on recent NetBSD (that both have
    utmpx & traditional utmp)
  * Moved setutmp() call from child to parent proces
    (not sure if this is right thing)
  * config.h.in, configure, configure.in, Wnn/uum/jhlp.c,
    Wnn/uum/setutmp.c, Wnn/uum/sheader.h:
  * Rewrote utmp code in uum (without libspt).
  * Because it cannot work on gcc with Linux/i386,
    temporally remove -fstack-check from CDEBUGFLAGS
    if you specify --enable-debug (and you're using gcc) .
  * Contrib/dic/gerodic/Makefile.in:
    Usual work:
  * Some modification in case if builddir != srcdir
    (Does not harm normal build.)
  * Wnn/uum/setutmp.c:
    In current setutmp.c code, saveut / nullut must be struct utmp.
    So removed struct utmpx statement.
    This will fix compile on systems that both have utmp.h and utmpx.h
    (e.g. NetBSD).
  * Wnn/uum/jhlp.c: Some minor fix for compiling some platforms:
  * crow is declared in header.h, so remove duplicate extern.
  * #ifdef-ed I_PUSH ptem / ldterm for platforms that don't have
    STREAMS but have ptsname (e.g. Linux, recent NetBSD) .
  * Wnn/uum/setutmp.c:
    Some minor change to fix compile error on Linux.
    UTMP feature is so complex to understand ...
  * configure, configure.in, makerule.mk.in:
  Modified WNNCNVFILEDIR to install correct cnv_* file
  if you're in terminfo environment.
  * CONTRIBUTORS, config.h.in, configure, configure.in,
    Wnn/conv/cvt_head.h, Wnn/conv/cvt_read.c,
    Wnn/include/commonhd.h, Wnn/include/wnn_os.h,
    Wnn/uum/Makefile.in, Wnn/uum/header.c,
    Wnn/uum/jhlp.c, Wnn/uum/sdefine.h, Wnn/uum/setutmp.c,
    Wnn/uum/sheader.h, Wnn/uum/termcap.c, Wnn/uum/termio.c,
    cWnn/uum/Makefile.in, kWnn/uum/Makefile.in:
    Long awaited merge of uum-related patch (based on hiroo's work
    in November, 2003)
  * Detect termcap / terminfo, curses etc. automatically
    (from canuum)
    But, configure support of libspt does not implemented /
    does not include Canna support / utmp implementation does not
    work correctly.
  * pty / pts processing (from Kabe). Auto detection in configure
    by hiroo.
  * Some modification due to build error in my environment.
  * Adding lines in case if builddir != srcdir .
    Many thanks to AIDA shinra, Taketo Kabe @ SRA Tohoku, hiroo,
    kouji at hiroshima-u.ac.jp (original author of Kabe's patch) .
  * makerule.mk.in, Wnn/romkan/Makefile.in,
    cWnn/romkan/Makefile.in, kWnn/romkan/Makefile.in:
    Some minor changes before large commit:
    makerule.mk.in:
  * Remove MAKE (if your make does not need this).
    You can build with other make command (ex. gmake) .
  * Define LT_{CC,LD,INSTALL} globally .
  * Wnn/romkan/Makefile.in:
  * Use LT_CC to remove warning.
  * (Usual work) changed some lines to build correctly
    in case builddir != srcdir . (I think this don't break
  normal build.)
  * Wnn/uum/: hinsi.c, jikouho.c, printf.c, termio.c, touroku.c:
  * Include string related header to reduce warning. (more merged
    from hiroo's work tree.)
  * Stripped old mail address (as usual) .
  * Wnn/uum/basic_op.c:
  * Include string related header to reduce warning.
    (Merged from hiroo's work tree.)
  * PubdicPlus/pod.c: Reverse condition of prototype section.
  * Wnn/include/commonhd.h: Increment _SERVER_VERSION for next
    (alpha?) release.
* Sun Dec 16 2012 schwab@linux-m68k.org
- Require library packages in devel packages
- Run ldconfig in %%post/%%postun
* Tue Dec 20 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Mon Mar 15 2010 ro@suse.de
- update to FreeWnn-1.1.1-a021
- disable parallel building again (not solid)
- fix build by using "-traditional-cpp" for "gcc -E"
* Fri Dec 18 2009 jengelh@medozas.de
- enable parallel building
* Thu Aug 28 2008 cthiel@suse.de
- fix init script
* Sat May 26 2007 ro@suse.de
- rename fwnndev subpackage to fwnn-devel
* Fri Mar 30 2007 ro@suse.de
- added ncurses-devel to buildreq
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 schwab@suse.de
- Don't strip binaries.
- Don't build as root.
* Fri Oct 21 2005 mmj@suse.de
- fix missing return value
* Thu Sep 22 2005 yxu@suse.de
- add needed prototypes
* Wed Jun 15 2005 meissner@suse.de
- Use RPM_OPT_FLAGS.
- Add lots of include files to avoid implicit declarations
- Use system getopt and bsearch.
- Fixed bad atoi() call spotted by -Wall
* Wed Apr 13 2005 mfabian@suse.de
- make it build on STABLE again: conflicting-prototypes.patch
* Tue Jun  8 2004 ro@suse.de
- get rid of some compiler warnings
* Mon Sep 15 2003 mfabian@suse.de
- Bugzilla #30921: /var/lib/wnn should be owned by user "wnn"
  for all subpackages.
* Mon Aug 18 2003 mfabian@suse.de
- Use new stop_on_removal/restart_on_upate macros
* Mon Jun 16 2003 mfabian@suse.de
- fix "directory not owned by any package".
* Sun Nov  3 2002 mfabian@suse.de
- Bug Id #17416: fix usage of socket API to make /usr/bin/jserver
  work on s390x. Thanks to <bk@suse.de> for help.
* Fri Sep 13 2002 mfabian@suse.de
- change "network route named" -> "$network $named" in
  "# Required-Start:".
* Thu Aug  1 2002 mfabian@suse.de
- add %%insserv_prereq %%fillup_prereq to Prereq:
* Wed Jul 24 2002 mfabian@suse.de
- Don't parse rc.config in init scripts
- change usage of useradd in pre script to comply with
  the package howto
- move home-dir into fwnncom sub package (fwnncom is required by
  all other *wnn* packages).
* Tue Jul  2 2002 ro@suse.de
- added home-dir to base package
* Thu Apr 11 2002 mfabian@suse.de
- use %%{_libdir} and add FreeWnn-lib64.patch from <froh@suse.de>
* Thu Jan 10 2002 egmont@suselinux.hu
- changed /sbin/init.d to /etc/init.d in init script comments
* Fri Dec  7 2001 mfabian@suse.de
- get rid of START_* variables in /etc/rc.config:
  use new macros fill_up_and_insserv and insserv_cleanup and
  remove testing for START_* variables from init scripts.
* Thu Sep  6 2001 mfabian@suse.de
- set START_FREE_TWNN="no", START_FREE_KWNN="no",
  START_FREE_CWNN="no",
* Tue Sep  4 2001 schwab@suse.de
- Add prototypes for C++, constify.
* Mon May  7 2001 mfabian@suse.de
- bzip2 sources
* Thu May  3 2001 mfabian@suse.de
- make init scripts comply with latest LSB spec
* Tue Dec  5 2000 schwab@suse.de
- Fix missing declarations.
* Tue Nov 28 2000 mfabian@suse.de
- forgot to change the links to the init scripts to /etc/init.d
  fixed.
* Mon Nov 27 2000 mfabian@suse.de
- removed sockets before starting the FreeWnn servers.
  sometimes these sockets remained after killing a FreeWnn server,
  which prevented the restart.
* Mon Nov 27 2000 mfabian@suse.de
- added "route named" to "Required-Start:"
- moved init scripts to /etc/init.d
* Fri Nov 24 2000 mfabian@suse.de
- change to new init script mechanism:
  rewrote the init scripts to use insserv to handle links to
  init scripts.
* Wed Nov  1 2000 mfabian@suse.de
- made the command line client "uum" work.
* Mon Oct 30 2000 mfabian@suse.de
- moved all manpages into the fwnncom subpackage
* Fri Oct 27 2000 bk@suse.de
- fixed startproc call, useradd and server permissions
* Wed Oct 25 2000 mfabian@suse.de
- new package: fwnn (FreeWnn, Version 1.1.1-a017)
